mathtools.all_are_positive_integer_powers_of_two
================================================

.. autofunction:: abjad.tools.mathtools.all_are_positive_integer_powers_of_two.all_are_positive_integer_powers_of_two
